@@ -17,9 +17,9 @@ from alibabacloud_dkms_transfer.handlers.get_secret_value_transfer_handler impor
 from alibabacloud_dkms_transfer.utils.consts import *
 
 
-class KmsTransferAcsClient(AcsClient):
+class KmsTransferAcsClient(AcsClient, object):
 
-    def __init__(self, config,
+    def __init__(self, config=None,
                  ak=None,
                  secret=None,
                  region_id="cn-hangzhou",
@@ -54,9 +54,13 @@ class KmsTransferAcsClient(AcsClient):
                            verify=verify,
                            pool_size=pool_size,
                            proxy=proxy)
-        self.handlers = dict()
-        self.client = Client(config)
-        self.init_kms_transfer_handlers()
+        if config is None:
+            self.is_use_kms_share_gateway = True
+        else:
+            self.is_use_kms_share_gateway = False
+            self.handlers = dict()
+            self.client = Client(config)
+            self.init_kms_transfer_handlers()
 
     def init_kms_transfer_handlers(self):
         self.handlers[ENCRYPT_API_NAME] = EncryptTransferHandler(self.client, ENCRYPT_API_NAME)
@@ -78,7 +82,7 @@ class KmsTransferAcsClient(AcsClient):
         self.handlers[GET_SECRET_VALUE_API_NAME] = GetSecretValueTransferHandler(self.client, GET_SECRET_VALUE_API_NAME)
 
     def _implementation_of_do_action(self, request, signer=None):
-        if self.handlers.__contains__(request.get_action_name()):
+        if not self.is_use_kms_share_gateway and self.handlers.__contains__(request.get_action_name()):
             return self.dispatch_dkms_action(request)
         return super(KmsTransferAcsClient, self)._implementation_of_do_action(request, signer)
 
